@@ -23,9 +23,16 @@
 #define MOD_TRACE	32
 #define MOD_MALLOC	64
 #define MOD_MMAP	128
+#define MOD_ACCESS	256
 
 #define TRACE_IN	1
 #define TRACE_OUT	2
 
-void	debug();
+void	_msqlDebug();
+void	_msqlTraced();
 void	initDebug();
+
+extern	int debugLevel;
+
+#define	msqlDebug	if(debugLevel) _msqlDebug
+#define	msqlTrace	if(debugLevel) _msqlTrace
