@@ -15,7 +15,7 @@ if test "$mode." != "."
 then
 	echo	"	$chmod $mode $dest"
 fi
-if test "$owner." != "."
+if test "$owner." = "root."
 then
 	echo	"	$chown $owner $dest"
 fi
