@@ -13,7 +13,7 @@ do
 	obj=`echo $src | sed "s/\.c\$/.o/"`
 	libobj="$libobj $obj"
 	echo	"$obj : $src"
-	echo	'	$(CC) $(CC_FLAGS) -c -o'" $obj $src"
+	echo	'	$(CC) $(CC_FLAGS) -c '"$src"
 	echo
 	echo	"clean ::"
 	echo	"	rm -f $obj"
