@@ -12,7 +12,7 @@ base=`echo $src | sed "s/\..*//"`
 echo
 echo	"# Make rules for building $obj"
 echo
-echo	"$obj : $src $deps"
+echo	"$obj : $src Makefile.full $deps"
 echo	'	$(CC) $(CC_FLAGS)'" -c $src"
 echo
 echo	"clean ::"
