@@ -113,9 +113,9 @@ int msqlLoadAcl(verbose)
 	{
 		if (verbose)
 		{
-			perror("Couldn't open ACL file");
+			perror("Warning : Couldn't open ACL file");
 		}
-		sprintf(packet,"-1:Couldn't open ACL file\n");
+		sprintf(packet,"-1:Warning - Couldn't open ACL file\n");
 		return(-1);
 	}
 
