@@ -48,6 +48,10 @@
 #define _LIB_SOURCE
 #include "msql.h"
 
+#ifndef	INADDR_NONE
+#define INADDR_NONE	-1
+#endif
+
 
 static	char	serverInfo[80],
 		hostInfo[80];
@@ -253,6 +257,7 @@ RETSIGTYPE pipeHandler(sig)
 {
 	msqlDebug(MOD_API,"Hit by pipe signal\n");
 	closeServer(curServerSock);
+	signal(SIGPIPE,pipeHandler);
 }
 
 
@@ -482,7 +487,7 @@ int msqlConnect(host)
 		** The server name may be a host name or IP address
 		*/
 	
-		if ((IPAddr = inet_addr(host)) != -1)
+		if ((IPAddr = inet_addr(host)) != INADDR_NONE)
 		{
 			bcopy(&IPAddr,&IPaddr.sin_addr,sizeof(IPAddr));
 		}
@@ -1014,7 +1019,7 @@ int readQueryData(sock)
 		{
 			len = atoi(cp);
 			cp = (char *)index(cp,':');
-			if (len == -1)
+			if (len == -2)
 			{
 				cur->data[off] = (u_char *)NULL;
 				cp++;
