@@ -17,9 +17,9 @@
 
 
 #if defined(__STDC__) || defined(__cplusplus)
-#  define __P(x)	x
+#  define __ANSI_PROTO(x)	x
 #else
-#  define __P(x)	()
+#  define __ANSI_PROTO(x)	()
 #endif
 
 #ifdef __cplusplus
@@ -83,25 +83,25 @@ typedef struct result_s {
 */
 #ifndef _MSQL_SERVER_SOURCE
 	extern  char msqlErrMsg[];
-	int 	msqlConnect __P((char *));
-	int 	msqlSelectDB __P((int, char*));
-	int 	msqlQuery __P((int, char*));
-	int 	msqlCreateDB __P((int, char*));
-	int 	msqlDropDB __P((int, char*));
-	int 	msqlShutdown __P((int));
-	int 	msqlReloadAcls __P((int));
+	int 	msqlConnect __ANSI_PROTO((char *));
+	int 	msqlSelectDB __ANSI_PROTO((int, char*));
+	int 	msqlQuery __ANSI_PROTO((int, char*));
+	int 	msqlCreateDB __ANSI_PROTO((int, char*));
+	int 	msqlDropDB __ANSI_PROTO((int, char*));
+	int 	msqlShutdown __ANSI_PROTO((int));
+	int 	msqlReloadAcls __ANSI_PROTO((int));
 	int 	msqlGetProtoInfo();
 	char 	*msqlGetServerInfo();
 	char 	*msqlGetHostInfo();
-	void	msqlClose __P((int));
-	void 	msqlDataSeek __P((m_result*, int));
-	void 	msqlFieldSeek __P((m_result*, int));
-	void 	msqlFreeResult __P((m_result*));
-        m_row   msqlFetchRow __P((m_result*));
-	m_field	*msqlFetchField __P((m_result *));
-	m_result *msqlListDBs __P((int));
-	m_result *msqlListTables __P((int));
-	m_result *msqlListFields __P((int, char*));
+	void	msqlClose __ANSI_PROTO((int));
+	void 	msqlDataSeek __ANSI_PROTO((m_result*, int));
+	void 	msqlFieldSeek __ANSI_PROTO((m_result*, int));
+	void 	msqlFreeResult __ANSI_PROTO((m_result*));
+        m_row   msqlFetchRow __ANSI_PROTO((m_result*));
+	m_field	*msqlFetchField __ANSI_PROTO((m_result *));
+	m_result *msqlListDBs __ANSI_PROTO((int));
+	m_result *msqlListTables __ANSI_PROTO((int));
+	m_result *msqlListFields __ANSI_PROTO((int, char*));
 	m_result *msqlStoreResult();
 #endif
 
