@@ -28,6 +28,7 @@
 #include <stdlib.h>
 #include <varargs.h>
 
+#include "version.h"
 
 #include "common/portability.h"
 
@@ -83,6 +84,7 @@ void sigTrap(sig)
 {
 	int	clientSock;
 
+	signal(sig,SIG_IGN);
 	fprintf(stderr,"\nHit by a sig %d\n\n",sig);
 	clientSock = 3;
 	printf("\n\nForced server shutdown due to bad signal!\n\n");
@@ -221,6 +223,7 @@ RETSIGTYPE puntServer(sig)
 {
 	int	clientSock;
 
+	signal(sig,SIG_IGN);
 	clientSock = 3;
 	if (sig == -1)
 	{
@@ -297,6 +300,7 @@ static setConnectionState(sock, fds)
 RETSIGTYPE puntClient(sig)
 	int	sig;
 {
+	signal(sig, puntClient);
 	if (clientFdSet)
 	{
 		FD_CLR(curComSock, clientFdSet);
@@ -407,7 +411,7 @@ main(argc,argv)
 		{
 			prog = argv[0];
 			argv[0] = BLANK_ARGV;
-			execvp(prog,argv,argc);
+			execvp(prog,argv);
 			perror("Exec failed");
 			exit(1);
 		}
@@ -425,6 +429,7 @@ main(argc,argv)
 	umask(0);
 	numCons=0;
 	chdir(msqlHomeDir);
+	printf("\n\nmSQL Server %s starting ...\n\n",SERVER_VERSION);
 	initDebug();
 	initNet();
 	initServer();
@@ -441,7 +446,7 @@ main(argc,argv)
 		fprintf(pidFile,"%d",getpid());
 		fclose(pidFile);
 	}
-	chmod(path,0744);
+	chmod(path,0644);
 	umask(0);
 	setupSignals();
 	msqlLoadAcl(1);
@@ -557,6 +562,8 @@ main(argc,argv)
 				msqlDebug(MOD_GENERAL,"Host = UNIX domain\n");
 			}
 
+			setConnectionState(newSock,&clientFDs);
+
 			if (!error)
 			{
 				opt=1;
@@ -605,9 +612,16 @@ main(argc,argv)
 		    {
 			setConnectionState(comSock,&clientFDs);
 			if (readPkt(comSock) <= 0)
+			{
+				msqlDebug(MOD_GENERAL,
+					"Command read on sock %d failed!\n",
+					comSock);
 				command = QUIT;
+			}
 			else
+			{
 				command = atoi(packet);
+			}
 			msqlDebug(MOD_GENERAL,"Command on sock %d = %d (%s)\n",
 				comSock, command, comTable[command]);
 			switch(command)
